@@ -1,5 +1,5 @@
 /* GADMIN-DHCPD - An easy to use GTK+ frontend for ISC DHCPD.
- * Copyright (C) 2004 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2004 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -155,7 +155,7 @@ void create_main_window(struct w *widgets)
 
 
     /* About button */
-    GtkWidget *toolbar_icon_credits = gtk_image_new_from_stock("gtk-justify-center", 
+    GtkWidget *toolbar_icon_credits = gtk_image_new_from_stock("gtk-about", 
                                       gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *credits_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
                                                           GTK_TOOLBAR_CHILD_BUTTON,
