@@ -1,5 +1,5 @@
 /* GADMIN-DHCPD - An easy to use GTK+ frontend for ISC DHCPD.
- * Copyright (C) 2004 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2004 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -59,12 +59,21 @@ void apply_settings_button_clicked(struct w *widgets)
     long file_size;
     char *line, *new_conf;
     gint active_index = 0;
-    gchar *cmd, *settings_file, *setting;
+    gchar *cmd, *info, *settings_file, *setting;
 
     G_CONST_RETURN gchar *conf_file = gtk_entry_get_text(GTK_ENTRY(widgets->settings_entry[0]));
     G_CONST_RETURN gchar *lease_file = gtk_entry_get_text(GTK_ENTRY(widgets->settings_entry[1]));
     G_CONST_RETURN gchar *default_lease_time = gtk_entry_get_text(GTK_ENTRY(widgets->settings_entry[2]));
 
+    if( conf_file[0]!='/' || lease_file[0]!='/' )
+    {
+	info = g_strdup_printf(_("Configuration or lease file path not valid.\n"));
+	show_info(info);
+	if( info!=NULL )
+	  g_free(info);
+	return;
+    }
+
     settings_file = g_strdup_printf("%s/settings.conf", SETTINGS_PATH);
 
     /* If the settings directory doesnt exist, create it */
@@ -100,20 +109,16 @@ void apply_settings_button_clicked(struct w *widgets)
     fclose(fp);
     g_free(settings_file);
 
-
     /* Make the paths current. */
     sprintf(DHCPD_CONF_BUF, "%s", conf_file);
     sprintf(LEASE_FILE_BUF, "%s", lease_file);
 
-
     if( ! file_exists((char *)conf_file) )
       printf("Creating a new dhcpd.conf here: %s\n", conf_file);
 
-
     /* Creates a default conf if its missing */
     add_missing_values((gchar *)conf_file);
 
-
     if((fp=fopen(DHCPD_CONF_BUF, "r"))==NULL)
     {
 	printf("Cant open: %s\n", DHCPD_CONF_BUF);
@@ -129,7 +134,7 @@ void apply_settings_button_clicked(struct w *widgets)
     /* DDNS update style */
     active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->settings_combo[0]));
     if( active_index <= 0 )
-      strcat(new_conf, "ddns-update-style ad-hoc;\n");
+      strcat(new_conf, "ddns-update-style none;\n");
     else
     if( active_index == 1 )
       strcat(new_conf, "ddns-update-style interim;\n");
@@ -311,8 +316,7 @@ void show_settings_window(struct w *widgets)
     GtkWidget *table;
     GtkWidget *settings_vbox;
     GtkTooltips *tooltips;
-    gchar *info;
-    gchar *utf8=NULL;
+    gchar *info, *utf8=NULL;
 
     widgets->settings_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     gtk_window_set_position(GTK_WINDOW (widgets->settings_window), GTK_WIN_POS_CENTER);
@@ -324,11 +328,10 @@ void show_settings_window(struct w *widgets)
     g_free(info);
 
     g_signal_connect(GTK_WINDOW(widgets->settings_window), "delete_event", 
-		     G_CALLBACK (gtk_widget_destroy), NULL);
+		     G_CALLBACK(gtk_widget_destroy), NULL);
 
     settings_vbox = gtk_vbox_new(FALSE, 0);
-    gtk_container_add (GTK_CONTAINER (widgets->settings_window), settings_vbox);
-
+    gtk_container_add(GTK_CONTAINER(widgets->settings_window), settings_vbox);
 
     tooltips = gtk_tooltips_new();
     frame = gtk_frame_new("Settings:");
@@ -400,15 +403,12 @@ void show_settings_window(struct w *widgets)
     /* Set default combo options */
     tmp = allocate(1024);
 
-    snprintf(tmp, 1000, "%s", _("Ad-hoc"));
+    snprintf(tmp, 1000, "%s", _("None"));
     utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[0]), utf8);
     snprintf(tmp, 1000, "%s", _("Interim"));
     utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[0]), utf8);
-    snprintf(tmp, 1000, "%s", _("None"));
-    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[0]), utf8);
 
     snprintf(tmp, 1000, "%s", _("Yes"));
     utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
@@ -479,17 +479,16 @@ void show_settings_window(struct w *widgets)
     utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->settings_combo[9]), utf8);
 
-    /* Select the first of every combo option */
+    /* Select the first option in every combo */
     for(i=0; i<10; i++)
        gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[i]), 0);
 
-    if( utf8!=NULL )
-      g_free(utf8);
-
     /* Insert values from dhcpd.conf if any */
     if((fp=fopen(DHCPD_CONF_BUF, "r"))==NULL)
     {
 	free(tmp);    
+	if( utf8!=NULL )
+	  g_free(utf8);
 	return;
     }
     fseek(fp, 0, SEEK_END);
@@ -513,12 +512,12 @@ void show_settings_window(struct w *widgets)
 	    /* Cut ; and newline */
 	    tmp[strlen(tmp)-2]='\0';
 	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-	    if( strcmp(tmp, "ad-hoc") == 0 )
+	    if( strcmp(tmp, "ad-hoc") == 0 ) /* Ad-hoc is deprecated so its set to none */
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[0]), 0);
+	    if( strcmp(tmp, "none") == 0 )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[0]), 0);
 	    if( strcmp(tmp, "interim") == 0 )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[0]), 1);
-	    if( strcmp(tmp, "none") == 0 )
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->settings_combo[0]), 2);
 	}
 	else
 	if( strstr(line, "ddns-updates") )
@@ -635,7 +634,6 @@ void show_settings_window(struct w *widgets)
     fclose(fp);
     free(line);
     free(tmp);
-
     if( utf8!=NULL )
       g_free(utf8);
 }
