@@ -1,5 +1,5 @@
 /* GADMIN-DHCPD - An easy to use GTK+ frontend for ISC DHCPD.
- * Copyright (C) 2004 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2004 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -66,7 +66,7 @@ void show_help(struct w *widgets)
 
     _("3. Dynamic name server updates:\n"),
     _("	To allow clients to dynamically update their information with a DNS server\n"),
-    _("	ddns update style should be set to ad-hoc or interim and the ddns updates\n"),
+    _("	ddns update style should be set to interim and the ddns updates\n"),
     _("	setting should be set to enabled in the settings window.\n"),
     _("	Client updates should be allowed if you want the clients to update their ddns-data.\n\n\n"),
 
