@@ -1,5 +1,5 @@
 /* GADMIN-DHCPD - An easy to use GTK+ frontend for ISC DHCPD.
- * Copyright (C) 2004 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2004 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,8 +47,8 @@ typedef struct w
   GtkWidget *onoff_label;
   GtkWidget *dhcpd_version_label;
   GtkWidget *scope_treeview;
-  GtkTreePath *scope_treepath;
   GtkListStore *scope_store;
+  GtkTreePath *scope_treepath;
 
   /* Add scope entries */
   GtkWidget *scope_add_nic_entry;
@@ -110,7 +110,9 @@ typedef struct w
   GtkWidget *loadbalance_upload_entry[NUM_LOADBALANCE_UPLOAD_ENTRIES];
   
   /* Leases tab */
-  GtkWidget *leases_textview;  
+  GtkWidget *lease_treeview;
+  GtkListStore *lease_store;
+  GtkTreeIter lease_iter;
 
   GtkWidget *credits_window;
 
